<?php 

class Fornecedores {

    public function Cadastrar(){
        global $database;

        if(isset($_POST['cadastrar'])){
            $nome = $_POST['nome'];
            $endereco = $_POST['endereco'];
            $cell1 = $_POST['cell1'];
            $cell2 = $_POST['cell2'];

        if($sql = $database->query("INSERT INTO fornecedores(nome,endereco,cell1,cell2)VALUES('$nome','$endereco','$cell1','$cell2')")){
            echo "<script>alert('$nome cadastrado com sucesso')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";
        }else{
             echo "<script>alert('Ocorreu um erro no cadastro')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";
        }
        }
    }

    public function Editar($id){
        global $database;
        if(isset($_POST['editar'])){
            $nome = $_POST['nome'];
            $endereco = $_POST['endereco'];
            $cell1 = $_POST['cell1'];
            $cell2 = $_POST['cell2'];
        if($sql = $database->query("UPDATE fornecedores SET nome='$nome',endereco='$endereco',cell1='$cell1',cell2='$cell2' WHERE id='$id'")){
           echo "<script>alert('$nome actualizado com sucesso com sucesso')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";
        }else{
             echo "<script>alert('Ocorreu um erro na actualizacao')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";
        }
      }
    }

 public function Listar(){
    global $database;
    $sql = $database->query("SELECT * FROM fornecedorescredito WHERE status='pendente'");
    return $sql;
 }

 public function ListarFornecedor(){
    global $database;
    $sql2 = $database->query("SELECT * FROM fornecedores");
    return $sql2;
 }

 public function SomaDivida(){
        global $database;

        $soma = $database->query("SELECT SUM(productTotal) as soma FROM fornecedorescredito WHERE status='pendente'");
        while($dados = $database->fetch_assoc($soma)){
            $somaTotal = $dados['soma'];
            return number_format($somaTotal,2,",",".");
        }
    }


 public function ListarArray(){
    global $database;
     $sql = $database->query("SELECT * FROM fornecedores");
     while($row = $database->fetch_assoc($sql)){
        $id = $row['id'];
        $nome = $row['nome'];

        echo "<option value='$id'>$nome</option>";
     }
 }

 public function Deletar(){
    global $database;
    if(isset($_GET['delete']) && !empty($_GET['delete'])){
        $id = $_GET['delete'];
        if($deletar = $database->query("DELETE FROM fornecedores WHERE id='$id'")){
           echo "<script>alert('Eliminado com sucesso')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";  
        }else{
             echo "<script>alert('FALHA AO DELETAR')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";
        }
    }
 }


  public function Txenekar(){
        global $database;

        if(isset($_POST['txenekar'])){
            $fornecedor = $_POST['supplyerName'];
            $producto = $_POST['productName'];
            $qtd = $_POST['productQtd'];
            $user = $_SESSION['nome'];
		    $data = date('Y-m-d');
            $dataPagamento = $_POST['dataPagamento'];

            $filtrarDados = $database->query("SELECT * FROM productos WHERE id='$producto'");
            $showDados = $database->fetch_assoc($filtrarDados);

            $nomeProducto = $showDados['productName'];
            $precoCompra = $showDados['productBuyPrice'];
            $quantidadeStock = $showDados['productQtd'];
            
            $totalVenda = $precoCompra * $qtd;
            $quantidadeNova = $quantidadeStock + $qtd;

            if($qtd < 0){
            echo "<script>alert('Quantidade inserida inferior a zero RECUSADO')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";
            }else{
            $sql = $database->query("INSERT INTO fornecedorescredito(productName,productQtd,productPrice,productTotal,supplyerName,status,data,dataPagamento,user)
            VALUES('$nomeProducto','$qtd','$precoCompra','$totalVenda','$fornecedor','pendente','$data','$dataPagamento','$user')");
           
           $update = $database->query("UPDATE productos SET productQtd='$quantidadeNova' WHERE id='$producto'");
                $message = "Txeneka efectuada com sucesso do fornecedor $fornecedor";
                $url = "fornecedores.php";
                echo "<script>window.open('alertas/alertas_good.php?message=$message&&url=$url','_self')</script>";
            }
        }
    }


    public function PagarTxenekaFornecedor(){
        global $database;
        if(isset($_GET['pagar']) && !empty($_GET['pagar'])){

            $idPagar = $_GET['pagar'];
            
            $data = date('Y-m-d');
            $sql = $database->query("SELECT * FROM fornecedorescredito WHERE id='$idPagar'");
            $mostraDados = $database->fetch_assoc($sql);

            $productName = $mostraDados['productName'];
            $productTotal = $mostraDados['productTotal'];

            $sql2 = $database->query("UPDATE fornecedorescredito SET status='pago' WHERE id='$idPagar'");
            $sql3 = $database->query("INSERT INTO caixa(descricao,valor,tipo,data)VALUES('Pagamento de divida de $productName','$productTotal','saida','$data')");
            
            if($sql2){
               echo "<script>alert('Divida paga com sucesso')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>"; 
            }else{
              echo "<script>alert('FALHA NO ENVIO DE PAGAMENTO')</script>";
            echo "<script>window.open('fornecedores.php','_self')</script>";
            }
            
        }
    }


}

$novoFornecedor = new Fornecedores();
?>